xsdata.formats.dataclass.serializers.json module
================================================

.. automodule:: xsdata.formats.dataclass.serializers.json
   :members:
   :undoc-members:
   :show-inheritance:
